VENUS_ETH = {
    "projectName": "Venus",
    "name": "Venus Lending Pool",
    "rewardToken": "0xd3cc9d8f3689b83c91b7b59cab4946b063eb894a",
    "comptrollerAddress": "",
    "lensAddress": "",
    "poolToken": "0xd3cc9d8f3689b83c91b7b59cab4946b063eb894a",
    "type": "LENDING_POOL",
    "forked": "compound",
}