VENUS_ARB = {
    "projectName": "Venus",
    "name": "Venus Lending Pool",
    "rewardToken": "0xc1eb7689147c81ac840d4ff0d298489fc7986d52",
    "comptrollerAddress": "",
    "lensAddress": "",
    "poolToken": "0xc1eb7689147c81ac840d4ff0d298489fc7986d52",
    "type": "LENDING_POOL",
    "forked": "compound",
}