MOONWELL_OPTIMISM = {
    "name": "MoonWell Lending Pool",
    "rewardToken": "",
    "comptrollerAddress": "0xca889f40aae37fff165bccf69aef1e82b5c511b9",
    "lensAddress": "",
    "poolToken": "0xa88594d404727625a9437c3f886c7643872296ae",
    "type": "LENDING_POOL",
    "forked": "compound",
}