VENUS_ZKSYNC = {
    "projectName": "Venus",
    "name": "Venus Lending Pool",
    "rewardToken": "0xd78abd81a3d57712a3af080dc4185b698fe9ac5a",
    "comptrollerAddress": "",
    "lensAddress": "",
    "poolToken": "0xd78abd81a3d57712a3af080dc4185b698fe9ac5a",
    "type": "LENDING_POOL",
    "forked": "compound",
}